# Integrated Cognative User Assistance 2 (icua)

### Quick install

COMING SOON

### Quick install (from source)

1. (Recommended) Create a virtual environment to better manage your python packages. See e.g. [anaconda](https://www.anaconda.com/), or [venv](https://docs.python.org/3/library/venv.html). 

2. Get latest version from git (main branch):
```
git clone https://github.com/dicelab-rhul/icua2.git
```
3. Install with pip:
```
pip install ./icua2
```
This will install all necessary dependencies.

4. Run:

Try one of the examples in

5. (Windows only) you may encounter the following error on first time install:
```
TODO
```
Follow the link and install GTK-3, after installing run again (step 4.) and the error should be fixed. If not, create an [issue](https://github.com/dicelab-rhul/icua2/issues) in this repository giving as much detail as you can.




### Matbii




Training videos and a summary of MATBII functionality can be found here.

https://matb.larc.nasa.gov/resources/videos/matb-ii-training-videos/
